/*  Copyright (C) 2010-2024 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "HLFCStrategy.h"
#include "../polar.h"
#include "../methods/generalMethods/auxFunctions.h"
#include "../methods/liftingLinePolar.h"
#include "../methods/liftingLineForTAW.h"
#include "../methods/viscDragRaymer.h"
#include "../methods/waveDragMason.h"
#include "../methods/semiEmpiricalHighLiftAdaption.h"
#include "../methods/trimInterpolation.h"

//#include <aircraftGeometry2/fuselage.h>
//#include <aircraftGeometry2/hull_surface.h>
//#include <aircraftGeometry2/processing/measure.h>
//#include <aircraftGeometry2/processing/transform.h>
//#include <aixml/node.h>
//#include <runtimeInfo/runtimeInfo.h>
//#include <moduleBasics/runtimeIO.h>
//#include <unitConversion/unitConversion.h>
//#include <CGAL/Surface_mesh/IO/PLY.h>
//#include <aircraftGeometry2/processing/transform.h>

#include <algorithm>
#include <exception>
#include <iomanip>
#include <string>
#include <memory>
#include <vector>
#include <filesystem>
#include <utility>  // make_pair

using std::endl;
using std::exception;
using std::fixed;
using std::ofstream;
using std::setprecision;
using std::string;
using std::stringstream;
using std::pair;
using std::vector;

/*  TODO:   - decide, where the component drags (induces, viscous and wave) get summed up
            - check if acft xml has entries before building the geometry comopnents */
HLFCStrategy::HLFCStrategy(const std::shared_ptr<RuntimeIO>& rtIO, const std::shared_ptr<laminarTAWConfig>& config)
    :
    CoGnames{"design", "front", "aft"},
    HLconfigs{"takeoff", "takeoff_landing_gear_retracted", "climb", "approach", "approach_landing_gear_out", "landing"},
    rtIO_(rtIO),
    config_(config) {
}