/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include <cmath>
#include <vector>
#include <numbers>
#include <memory>
#include <moduleBasics/module.h>
#include <string>
#include <vector>
#include <unordered_map>
#include "ca_strategy.h"

#ifndef SRC_CONSTRAINT_ANALYSIS_H_
#define SRC_CONSTRAINT_ANALYSIS_H_


class DefaultAnalysis : public Module{
public:

    DefaultAnalysis(const int argc, char **argv, const std::string &toolName, const std::string &toolVersion)
        : Module(argc, argv, toolName, toolVersion)
    {
    }

    DefaultAnalysis(const std::string& toolName, const std::string& toolVersion, const std::filesystem::path& rtConfigXML)
        : Module(toolName, toolVersion, rtConfigXML)
    {
    }

    ~DefaultAnalysis() = default;

    void initialize() override;
    void run() override;
    void update() override;
    void report() override;
    void save() override;

private:

    std::unique_ptr<ConstraintAnalysisStrategy> constraint_analyzer;
    std::shared_ptr<node> configuration_xml;
    std::shared_ptr<node> aircraft_xml;
    double thrust_to_weight_point = 0.0;
    double wing_loading_point = 0.0;
    std::filesystem::path engine_directory;
    std::filesystem::path mission_directory;
};

#endif