/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

 /* === Includes === */
#include <gtest/gtest.h>
#include <aixml/node.h>

/* Unit Under Test */
#include "constraint_analysis/ca_parser.h"

TEST(readPolar, initialization)
{
    std::filesystem::path file{CMAKE_TEST_STUBS_DIR};
    std::filesystem::path polarFile = file / "CSMR-2020_polar.xml";
    const std::string& aConfig = "Clean";
    EXPECT_EQ(std::filesystem::exists(polarFile),true);
    readPolar clean_config(aixml::openDocument(polarFile), aConfig, "linear", 0.2);
};

TEST(readPolar, interp)
{
    std::filesystem::path file{ CMAKE_TEST_STUBS_DIR };
    std::filesystem::path polarFile = file / "CSMR-2020_polar.xml";
    const std::string& aConfig = "Clean";
    EXPECT_EQ(std::filesystem::exists(polarFile), true);
    readPolar clean_config(aixml::openDocument(polarFile), aConfig, "linear", 0.2);
    const double CD = clean_config.interpCD(-0.2985);
    EXPECT_NEAR(CD, 0.0236150, 1e-5);
};

TEST(readPolar, getCD)
{
    std::filesystem::path file{ CMAKE_TEST_STUBS_DIR };
    std::filesystem::path polarFile = file / "CSMR-2020_polar.xml";
    const std::string& aConfig = "Clean";
    EXPECT_EQ(std::filesystem::exists(polarFile), true);
    readPolar clean_config(aixml::openDocument(polarFile), aConfig, "linear", 0.2);
    const double CD = clean_config.getCD(100, 1, 0.9, 0.2, 1000);
    EXPECT_NEAR(CD, 0.019746, 1e-5);
};

TEST(readPolar, get_coefficients)
{
    std::filesystem::path file{ CMAKE_TEST_STUBS_DIR };
    std::filesystem::path polarFile = file / "CSMR-2020_polar.xml";
    const std::string& aConfig = "Clean";
    EXPECT_EQ(std::filesystem::exists(polarFile), true);
    readPolar clean_config(aixml::openDocument(polarFile), aConfig, "linear", 0.2);
    std::vector<double> coeffs = clean_config.quadratic_coefficients();
    EXPECT_NEAR(coeffs[0], 0.047164, 1e-5); //K1
    EXPECT_NEAR(coeffs[1], -0.00611, 1e-5); //K2
    EXPECT_NEAR(coeffs[2], 0.019369, 1e-5); //CD0
};