# Getting started
This section will guide you through the necessary steps to get the _cost\_estimation_ module up and running. It contains information on tool requirements and design parameters.
- [Aircraft exchange file](#aircraft-exchange-file) - Get information on necessary parameters from the _acXML_.
- [Module configuration file](#module-configuration-file) - Dive into cost estimation specific parameters.
- [Additional requirements](#additional-requirements) - Is anything else necessary to get the module running?
- [Next steps](#next-steps) - How to proceed?

@note It is assumed that you have the `UNICADO package` installed including the executables and UNICADO libraries.

Generally, we use two files to set or configure modules in UNICADO:
- The aircraft exchange file (or _acXML_) includes
    - data related inputs (e.g., aircraft configuration, transport task) and
    - data related outputs (e.g., annual direct operating costs).
- The module configuration file `cost_estimation_conf.xml` (also _configXML_) includes
    - control settings (e.g., enable/disable generating plots) and
    - program settings (e.g., fees, usage information).

In the following sections you will find more information on how to configure these files to suit your needs.

## Aircraft exchange file requirements {#aircraft-exchange-file}
Since the _cost\_estimation_ module is an assessment tool, it is assumed that a converged aircraft design and therefore all the necessary data are already available.

The following information is needed from the _acXML_:
1. Design specification
    - Configuration information: Configuration type
    - Transport task: Passenger definition, passenger class definition, and cargo definition
    - Energy carrier(s)
2. Top level aircraft requirements (for design and study mission - if desired)
    - Initial cruise mach number
    - Initial cruise altitude
    - Payload fractions (seat load factor, only required for study mission assessment)
3. Component design
    - Fuselage: Number of required cabin crew, number of required flight crew
    - Propulsion: Sea level static thrust per engine
4. Analysis
    - Masses: Maximum takeoff mass (certified), takeoff mass (for design and study - if desired), operating mass empty, maximum payload mass
    - Mission (for design and study mission - if desired)
        - Stage length
        - Flight time
5. Assessment (aka. payload range data)
    - Range at maximum payload and fuel mass till maximum take off mass limit
    - Range at full tanks and payload till maximum take off mass limit
    - Range for no payload and full tanks (ferry range)
    - Payload at full tanks and payload till maximum take off mass limit

## Module configuration file {#module-configuration-file}
The _configXML_ is structured into two blocks: the control and program settings.

The control settings are standardized in UNICADO and will not be described in detail here. But to get started, you have to change at least
- the `aircraft_exchange_file_name` and `aircraft_exchange_file_directory` to your respective settings,
- the `console_output` at least to `mode_1`, and
- the `plot_output` to false (or define `inkscape_path` and `gnuplot_path`).

@note If the tool is executed via the workflow, those settings are set by the workflow settings.

The program settings are structured like this (descriptions can be found in the `cost_estimation_conf.xml`):

```plaintext
Program Settings
|- Configuration (ID="tube_and_wing")
|  |- Fidelity name
|  |- Method name
|  |- Fidelity (ID="empirical")
|  |  |- Operating cost estimation tu berlin
|  |  |  |- General direct operating costs parameter
|  |  |  |  | - Capital
|  |  |  |  |  | - Depreciation period
|  |  |  |  |  | - Price per operating empty mass
|  |  |  |  |  | - Rate insurance
|  |  |  |  |  | - Rate interest
|  |  |  |  |  | - Residual value factor
|  |  |  |  | - Crew
|  |  |  |  |  | - Salary variation
|  |  |  |  | - Flight cycles
|  |  |  |  |  | - Block time per flight
|  |  |  |  |  | - Daily night curfew time
|  |  |  |  |  | - Potential annual operation time
|  |  |  |  |  | - Annual lay days overhaul
|  |  |  |  |  | - Annual lay days reserve
|  |  |  |  |  | - Annual lay days maintenance
|  |  |  |  | - Handling
|  |  |  |  |  | - Fees handling
|  |  |  |  | - Landing
|  |  |  |  |  | - Fees landing
|  |  |  |  | - Air traffic control
|  |  |  |  |  | - Air traffic control price factor design
|  |  |  |  |  | - Air traffic control price factor study
|  |  |  |  | - Maintenance
|  |  |  |  |  | - Airframe repair cost per flight
|  |  |  |  |  | - Cost burden
|  |  |  |  |  | - Rate labor
|  |  |  |  | - Related direct operating costs
|  |  |  |  |  | - Revenue per freight km design
|  |  |  |  |  | - Revenue per freight km study
|  |  |  |  | - Miscellaneous
|  |  |  |  |  | - Rate inflation
|  |  |  |- Fuel type (ID="kerosene")
|  |  |  |  | - Factor engine maintenance
|  |  |  |  | - Fuel price
|  |  |  |  | - Ratio operating empty mass
|  |  |  |- Fuel type (ID="liquid_hydrogen")
|  |  |  |  | - Factor engine maintenance
|  |  |  |  | - Fuel price
|  |  |  |  | - Ratio operating empty mass
```

## Additional requirements {#additional-requirements}
The tool requires mission-dependent data. Please make sure that the `mission_data` folder, located in the directory of the aircraft exchange file, contains at least the `design_mission.xml` file (this should be the case if the design is valid). If data for an off-design analysis is available and you wish to calculate the associated costs, the `study_mission.xml` file must also be provided.

## Next steps {#next-steps}
The next step is to [run the _cost\_estimation_ module](run_your_first_cost_estimation.md).