/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 * 
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include <memory>
#include <map>
#include <string>
#include <vector>

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

#include "create_mission_xml.h"
#include "standard_mission/standard_mission/standard_mission.h"

/**
 * @brief Construct a new CreateMissionXML:: CreateMissionXML object
 * 
 * @param tool_name entry from toolinfo.h
 * @param tool_version entry from toolinfo.h
 */
CreateMissionXML::CreateMissionXML(const int argc, char *argv[], const std::string &tool_name,
                                 const std::string &tool_version)
    : Module(argc, argv, tool_name, tool_version) {
    std::string mission_type = EndnodeReadOnly<std::string>("program_settings/mission_selector").read(rtIO_->moduleConfig).value();

    mission_strategy_.registerStrategy<design_mission::StandardMission>      ({"design_mission"});
    mission_strategy_.registerStrategy<study_mission::StandardMission>       ({"study_mission"});
    mission_strategy_.registerStrategy<requirements_mission::StandardMission>({"requirements_mission"});
    mission_strategy_.setStrategy({mission_type}, rtIO_);
}
