/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef ECOLOGICAL_ASSESSMENT_SRC_ECOLOGICAL_ASSESSMENT_H_
#define ECOLOGICAL_ASSESSMENT_SRC_ECOLOGICAL_ASSESSMENT_H_

#include "aixml/node.h"
#include <moduleBasics/module.h>
#include <moduleBasics/report.h>
#include <moduleBasics/strategySelector.h>
#include <aixml/endnode.h>
#include <string>
#include <vector>
#include <memory>

/** \class EcologicalAssessment
 * \brief Base class for ecological assessment
 */
class EcologicalAssessment : public Module {
 public:
 /** \brief Constructor of class EcologicalAssessment
  * \param argc The number of command line arguments.
  * \param argv The command line arguments.
  * \param toolName The name of the tool.
  * \param toolVersion The version of the tool.
  */
  EcologicalAssessment(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion);
  EcologicalAssessment(const std::string& toolName, const std::string& toolVersion, const std::filesystem::path& rtConfigCML)
      : Module(toolName, toolVersion, rtConfigCML) {}
  /** \brief Destructor of EcologicalAssessment object
   */
  ~EcologicalAssessment() = default;

  void initialize() override { strategy_.initializeStrategy(); }
  void run() override { strategy_.runStrategy(); };
  void update() override { strategy_.updateStrategy(); };
  void report() override { strategy_.reportStrategy(); };
  void save() override { strategy_.saveStrategy(); rtIO_->saveAndCloseAcXML(); rtIO_->closeModuleConfig(); };

 private:
  StrategySelector strategy_; /**< Strategy */
};


#endif // ECOLOGICAL_ASSESSMENT_SRC_ECOLOGICAL_ASSESSMENT_H_
