/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_LIFE_CYCLE_EMISSIONS_LCA_SCHAEFER_CALCULATEEMISSIONS_SCHAEFER_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_LIFE_CYCLE_EMISSIONS_LCA_SCHAEFER_CALCULATEEMISSIONS_SCHAEFER_H_

#include <memory>
#include <vector>
#include <string>
#include <moduleBasics/strategySelector.h>
#include <moduleBasics/report.h>
#include <moduleBasics/plot.h>
#include <moduleBasics/runtimeIO.h>
#include <aixml/node.h>
#include "schaeferIOData.h"
#include "../../ecoDatabase.h"
#include "production.h"
#include "operation.h"
#include "endOfLife.h"
#include "development.h"

/** \class LifeCycleEmissionsSchaefer
 * \brief Class for emission calculation according to K. Schaefer
 *
 */
class LifeCycleEmissionsSchaefer {
 public:
   /** \brief Constructor of class LifeCycleEmissionsSchaefer
    */
    LifeCycleEmissionsSchaefer() {}
    /** \brief Destructor of class LifeCycleEmissionsSchaefer */
    ~LifeCycleEmissionsSchaefer() = default;

    /** \brief Runs life cycle emission calcualtion according to Schaefer 2011*/
    void run(const std::shared_ptr<RuntimeIO> &rtIO, std::shared_ptr<node> ecoAssXML);

    std::shared_ptr<SchaeferIOData> schaeferIOData; /**< IOData object*/
    Development theDevelopment;/**< Object contains data for the entire certification process (i.e. for the entire aircraft program) */
    Production theProduction;/**< Object of class Productionthat contains production data */
    Operation theOperation;/**< Object contains operation data */
    EndOfLife theEndOfLife;/**< Object contains end of life data */
};

#endif //ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_LIFE_CYCLE_EMISSIONS_LCA_SCHAEFER_CALCULATEEMISSIONS_SCHAEFER_H_
