/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSIONSCLASS_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSIONSCLASS_H_

/** \class Emissions
 * \brief Class contains emissions and potentials
 */
class Emissions {
 public:
    /*Emissions*/
    double CO2; /**< Carbon dioxide [kg]*/
    double H2O;/**< Water emission [kg]*/
    double NOx;/**< Nitrogen oxides [kg]*/
    double CO;/**< Carbon monoxide [kg]*/
    double SO2;/**< Sulphur dioxide [kg]*/
    double SO4;/**<Optically active sulfate [kg] */
    double CH4;/**< Methane [kg]*/
    double PM10;/**< Particulate matter (for mission: it is assumed that PM consists only of soot -> PM10 = soot) [kg]*/
    double soot; /**< Soot [kg] */
    double N2O;/**< Nitrous oxide (laughing gas) [kg]*/
    double PFC;/**< Perfluorinated hydrocarbons [kg]*/
    double NMVOC;/**< Non methane volatile organic compounds [kg]*/
    double HC; /**< Hydrocarbon [kg]*/

    /*Potentials*/
    double GWP100;/**< Global Warming Potential for a 100 year time frame [1/MJ] or [1/kg]*/
    double AP;/**< Acidification Potential [1/MJ] or [1/kg]*/
    double ADP;/**< Abiotic Resource Depletion Potential [1/MJ] or [1/kg]*/
    double POCP;/**< Photochemical Ozone Creation Potential [1/MJ] or [1/kg] */
    double OLDP;/**< Ozone Layer Depletion Potential [1/MJ] or [1/kg] */
    double PMFP;/**< Particulate Matter Formation Potential [1/MJ] or [1/kg] */
    double CED;/**< Cumulative Energy Demand [MJ]*/

    /** \brief Constructor of class Emissions
     */
    Emissions();

    /** \brief Destructor of class Emissions
     */
    virtual ~Emissions() {}
};

#endif // ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSIONSCLASS_H_
