/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "AQISchaeferIOData.h"
#include <aixml/node.h>
#include <aixml/endnode.h>
#include <vector>


AQISchaeferIOData::AQISchaeferIOData(std::shared_ptr<RuntimeIO> rtIO, std::shared_ptr<node> ecoAssXML)
    :
    myEngine(rtIO->getEngineDataDir() + "/" +
            EndnodeReadOnly<std::string>("component_design/propulsion/specific/propulsion/engine/model").read(rtIO->acxml).value(),
            EndnodeReadOnly<double>("component_design/propulsion/specific/propulsion/engine/scale_factor").read(rtIO->acxml).value()),
    number_of_engines(rtIO->acxml.getVector("aircraft_exchange_file/component_design/propulsion/specific/propulsion/").size()),
    CO_LTO(0.),
    HC_LTO(0.),
    NOx_LTO(0.),
    c_soot_LTO_max(0.) {
        read_ecological_assessment_xml(*ecoAssXML);
    }

/* Input data methods*/
void AQISchaeferIOData::read_ecological_assessment_xml(const node& ecoAssXML) {
    std::string emissions_path("ecological_data_file/mission_emissions/study_mission/emissions/");
    c_soot_LTO_max = EndnodeReadOnly<double>("LTO_cycle/c_soot_LTO_max").read(ecoAssXML.at(emissions_path)).value()*pow(10, 6);
    NOx_LTO =  EndnodeReadOnly<double>("LTO_cycle/NOx").read(ecoAssXML.at(emissions_path)).value();
    HC_LTO =  EndnodeReadOnly<double>("LTO_cycle/HC").read(ecoAssXML.at(emissions_path)).value();
    CO_LTO =  EndnodeReadOnly<double>("LTO_cycle/CO").read(ecoAssXML.at(emissions_path)).value();
}

/* Output data methods*/


