/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQIschaeferIODataH_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQIschaeferIODataH_

#include <string>
#include <vector>
#include <memory>
#include <moduleBasics/runtimeIO.h>
#include <engine/engine.h>
#include <aixml/node.h>

/** \class  AQISchaeferIOData
 * \brief Data class for air qualitiy index calculation according to Schaefer
 */
class AQISchaeferIOData {
 public:
    /* Input parameter*/
    Engine myEngine; /**< Engine object */
    double number_of_engines; /**< Number of engines [-]*/
    double CO_LTO; /**< CO emissions mass of study mission LTO[kg]*/
    double HC_LTO; /**< HC emissions mass of study mission LTO[kg]*/
    double NOx_LTO; /**< NOx emissions mass of study mission LTO [kg]*/
    double c_soot_LTO_max;/**< Maximum soot concentration during Landing and Takeoff of study mission [mg/kg]*/

    /** \brief construct a new schaefer IO data object
     * \param rtIO Access to runtime IO
     * \param ecoAssXML Node of ecological assessment results xml
     */
    explicit AQISchaeferIOData(std::shared_ptr<RuntimeIO> rtIO, std::shared_ptr<node> ecoAssXML);

    /** \brief Destructor of class SchaeferIOData
     */
    virtual ~AQISchaeferIOData() {}

    /** \brief Funtions reads data from ecological asessment results xml
     * \param ecoAssXML Node of eco xml
     */
    void read_ecological_assessment_xml(const node& ecoAssXML);
};

#endif // ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQIschaeferIODataH_
