/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQI_SCHAEFER_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQI_SCHAEFER_H_

#include <memory>
#include <vector>
#include <string>
#include <moduleBasics/runtimeIO.h>
#include <atmosphere/atmosphere.h>
#include <aixml/node.h>
#include "AQISchaeferIOData.h"

/** \class AQISchaefer
 * \brief Class for air quality index calculation accordign to Schaefer (2017) \cite Sch17
 */
class AQISchaefer {
 public:
    /** \brief Constructor of class AQISchaefer
     */
    AQISchaefer();
    /** \brief Destructor of class AQISchaefer */
    ~AQISchaefer() = default;

    /** \brief Function to run Schaefer AQI method
     * \param rtIO Access to rtIO
     * \param ecoAssXML Pointer to node of ecological assessment results
     */
    void run(const std::shared_ptr<RuntimeIO> &rtIO, std::shared_ptr<node> ecoAssXML);

    /** \brief Function to calculate the air quality index according to Schaefer (2017) \cite Sch17
    */
    void calculateAQISchaefer(const std::string &fuelType);

    atmosphere myAtmosphere;/**< Atmosphere object */
    std::shared_ptr<AQISchaeferIOData> AQIschaeferIOData; /**< Pointer to ioData */
    double tolerance_CO;/**< Tolerance factors of CO emissions emitted during LTO [-] */
    double tolerance_HC;/**< Tolerance factors of HC emissions emitted during LTO [-] */
    double tolerance_NOx;/**< Tolerance factors of NOx emissions emitted during LTO [-] */
    double tolerance_soot;/**< Tolerance factors of soot emissions emitted during LTO [-] */
    double AQI;/**< AIr quality index [-] */
};

#endif //ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQI_SCHAEFER_H_
