/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "dallaraConfig.h"

#include <aixml/node.h>

DallaraConfig::DallaraConfig()
    :
    forcing_factor_variation_AIC(0.),
    forcing_factor_variation_O3S(0.),
    forcing_factor_variation_CH4O3L(0.),
    fuelAICfactor(0.),
    forcing_factor_dataset(""),
    tmax(0),
    devRate(0.) {
    }

void DallaraConfig::read_all_config_data(const node& configXML) {
    fuelAICfactor = EndnodeReadOnly<double>(std::string("program_settings/standard_strategy/impact_calculation/")
                    + std::string("climate_model_methods/dallara/fuel_factor_AIC")).read(configXML).value();
    tmax = EndnodeReadOnly<int>(std::string("program_settings/standard_strategy/impact_calculation/")
            + std::string("climate_model_methods/dallara/max_integration_period")).read(configXML).value_xml();
    devRate = EndnodeReadOnly<double>(std::string("program_settings/standard_strategy/impact_calculation/")
                + std::string("climate_model_methods/dallara/devaluation_rate")).read(configXML).value();
    read_forcing_factor_config_data(configXML.at("program_settings/standard_strategy/impact_calculation/climate_model_methods/dallara/forcing_factors"));
}

void DallaraConfig::read_forcing_factor_config_data(const node& forcingFactor) {
    forcing_factor_variation_AIC = EndnodeReadOnly<double>("/variations/aircraft_induced_cloudiness").read(forcingFactor).value();
    forcing_factor_variation_O3S = EndnodeReadOnly<double>("/variations/short_lived_ozone").read(forcingFactor).value();
    forcing_factor_variation_CH4O3L = EndnodeReadOnly<double>("/variations/methan_and_long_lived_ozone").read(forcingFactor).value();
    forcing_factor_dataset = EndnodeReadOnly<std::string>("/data_set_selector").read(forcingFactor).value();
}

DallaraConfig::~DallaraConfig() {
    //dtor
}

