/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef EMPENNAGEDESIGN_SRC_BWB_VERTICALTAILSDATA_H_
#define EMPENNAGEDESIGN_SRC_BWB_VERTICALTAILSDATA_H_

#include <aircraftGeometry2/geometry/factory.h>
#include <aircraftGeometry2/io/convert.h>

#include "lib/io_methods/massPropertiesIO.h"
#include "lib/io_methods/positionIO.h"

namespace bwb {
namespace low {

class VerticalTailsData {
 public:
  VerticalTailsData();

  void read(const node& xml);
  void read_wing(std::filesystem::path path, std::filesystem::path airfoil_data_dir);

  void update(node& xml);
  void update_vertical_tails(node& xml);

  std::vector<geom2::MultisectionSurface<geom2::AirfoilSection>> tails;
  std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> controls;
  std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> spars;
  std::vector<MassPropertiesIO> tails_mass;
  MassPropertiesIO empennage_mass;
  PositionIO empennage_position;

  geom2::MultisectionSurface<geom2::AirfoilSection> wing;
  MassPropertiesIO maximum_takeoff_mass;
  PositionIO wing_reference_position;
};
}  // namespace low
}  // namespace bwb

#endif  // EMPENNAGEDESIGN_SRC_BWB_VERTICALTAILSDATA_H_
