/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef LOW_VERTICAL_TAILS_BWB_H_
#define LOW_VERTICAL_TAILS_BWB_H_

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

#include <functional>
#include <map>

#include "bwb/vertical_tails/bwbVerticalTailsConfig.h"
#include "bwb/vertical_tails/bwbVerticalTailsData.h"

namespace bwb {
namespace low {

class VerticalTails : public Strategy {
 public:
  VerticalTails(const std::shared_ptr<RuntimeIO>& rtIO);
  ~VerticalTails() = default;
  void initialize();
  void run();
  void update();
  void report();
  void save();

  void design();
  void redesign();

  void flops_mass();

  const std::shared_ptr<RuntimeIO>& rtIO;
  const std::shared_ptr<bwb::low::VerticalTailsConfig> config;
  const std::shared_ptr<bwb::low::VerticalTailsData> data;
  std::map<std::string, std::function<void(void)>> design_mode;
  std::map<std::string, std::function<void(void)>> mass_mode;
};

}  // namespace low
}  // namespace bwb

#endif  // LOW_VERTICAL_TAILS_H_