# Calculation method

- [Determination of cabin geometry](#cabin-geometry)
- [Determination of fuselage geometry](#fuselage-geometry)
- [Estimation of masses](#mass-estimation)
- [Generation of fuselage shape](#generate-shape)

@note Currently the tool supports only one fuselage with one payload tube.

## Determine cabin geometry {#cabin-geometry}
### Cabin width
The cabin width is estimated using the given class definition.

#### Determine width of seat row per aircraft side
The width of one seat row/bench \f$w_{seat\_bench}\f$ (in inch) can be determined for the left and right side of the aircraft using the following equation:
\f[
    w_{seat\_bench} = n_{seats} \cdot w_{seat} + 2 \cdot w_{armrest}
\f]

In which
- \f$n_{seats}\f$ - number of seats per seat bench
- \f$w_{seat}\f$ - seat width (taken from lowest class seat)
- \f$w_{armrest}\f$ - armrest width (taken from lowest class seat)

#### Calculate cabin width
The cabin width \f$w_{cabin}\f$ (in inch) can then be calculated:
\f[
    w_{cabin} = w_{aisle} + w_{seat\_bench\_left} + w_{seat\_bench\_right} + 2 \cdot w_{seat\_space}
\f]

In which
- \f$w_{aisle}\f$ - passenger aisle width
- \f$w_{seat\_space}\f$ - lowest class seat space

In case of a **wide-body aircraft configuration** there is an additional row in the middle of the aircraft as well as an additional passenger aisle. The width of the seat bench \f$w_{seat\_bench\_center}\f$ can be calculated using an equation similar to that in the previous section.
\f[
    w_{seat\_bench\_center} = n_{seats} \cdot w_{seat} + 2 \cdot w_{armrest\_outer} + (n_{seats} - 1) \cdot w_{armrest\_inner}
\f]

In which
- \f$w_{seat}\f$ - seat width (from lowest class seat parameters of right side)
- \f$w_{armrest\_outer}\f$ - width of outer armrest (from lowest class seat parameters of right side)
- \f$w_{armrest\_inner}\f$ - width of inner armrest (from lowest class seat parameters of right side)

The equation for the cabin width estimation must be adapted accordingly:
\f[
    w_{cabin} = w_{aisle} + w_{seat\_bench\_left} + w_{seat\_bench\_right} + 2 \cdot w_{seat\_space} + w_{aisle} + w_{seat\_bench\_center}
\f]

### Cabin slenderness ratio <sup>[1]</sup>
The cabin slenderness ratio describes the ratio of cabin width to cabin length \f$\frac{w_{cabin}}{l_{cabin}}\f$.
Whilst the cabin width is already known, the cabin length can be determined using the following equation:
\f[
    l_{cabin} = \frac{n_{PAX\_per\_class}}{ab} \cdot \left[ sp + \frac{a_{service}}{w_{seat}} + \frac{a_{bulk}}{\frac{w_{aisle}}{ab} + w_{seat}} + x \cdot w_{exit} \cdot \left( \frac{ab}{n_{PAX\_per\_class}} + \frac{sp}{d_{exits}} \right)  \right]
\f]

In which
- \f$x\f$ - factor (1 for single-aisle, 2 for wide-body)
- \f$n_{PAX\_per\_class}\f$ - number of PAX per class
- \f$ab\f$ - seat abreast
- \f$sp\f$ - seat pitch
- \f$a_{service}\f$ - service area per PAX
- \f$a_{bulk}\f$ - bulk area per PAX
- \f$w_{exit}\f$ - exit width
- \f$d_{exits}\f$ - maximum distance between two exits

### Cabin length
Knowing the cabin width and the cabin slenderness ratio, the cabin length (in inch) can be calculated:
\f[
    l_{cabin} = \frac{w_{cabin}}{\frac{w_{cabin}}{l_{cabin}}}
\f]

### Cabin wall thickness
The cabin wall thickness can be estimated using the following calculation:
\f[
    t_{wall} = 0.02 \cdot w_{cabin} + 2.5"
\f]

### Cabin floor thickness
With the use of the cabin wall thickness, the cabin floor thickness can be calculated:
\f[
    t_{floor} = 1.5 \cdot t_{wall}
\f]

## Determine fuselage geometry {#fuselage-geometry}
With the calculated cabin the fuselage dimensions can be estimated.

### Fuselage length<sup>[2]</sup>
The fuselage length can be determined via regression formulas using the cabin length (in meter).

For single-aisle aircraft:
\f[
    l_{fuselage} = \frac{l_{cabin}}{0.23482756 \cdot \log l_{cabin} - 0.05106017}
\f]

For wide-body aircraft:
\f[
    l_{fuselage} = \frac{l_{cabin}}{0.1735 \cdot \log l_{cabin} - 0.0966}
\f]

### Fuselage diameters
The fuselage does not necessarily have a circular cross-section. It is more common to design elliptical cross-sections. Because of that, there are several values that must be determined:
- Fuselage diameter in y-direction
- Fuselage diameter in negative z-direction
- Fuselage diameter in positive z-direction

#### Fuselage diameter in y-direction
The fuselage diameter in y-direction \f$d_{fuselage\_y}\f$ can be calculated in the following way:
\f[
    d_{fuselage\_y} = w_{cabin} + 2 \cdot t_{wall}
\f]

#### Fuselage diameter in negative z-direction
The fuselage diameter in negative z-direction \f$d_{fuselage\_z\_neg}\f$ is determined by the cargo accommodation. It can be calculated in the following way.
At first, the distance to the cargo bottom is calculated:
\f[
    d_{to\_cargo\_bottom} = h_{max} + t_{floor} + d_{container\_to\_ceil} + o_{cabin\_floor}
\f]

In which
- \f$h_{max}\f$ - maximum height of unit load device
- \f$d_{container\_to\_ceil}\f$ - distance from the container to the ceiling
- \f$o_{cabin\_floor}\f$ - offset cabin floor

Afterwards, the distance to the lower compartment edge is estimated:
\f[
    d_{to\_lower\_compartment\_edge} = d_{container\_to\_wall} + 0.5 \cdot w_{max\_at\_base}
\f]
In which
- \f$d_{container\_to\_wall}\f$ - distance from container to wall
- \f$w_{max\_at\_base}\f$ - maximum width at container base

Based on the Pythagorean theorem, the inner fuselage diameter (that equals the hypotenuse) can be calculated:
\f[
    d_{inner\_fuselage\_z\_neg} = \sqrt{(d_{to\_cargo\_bottom})^2 + (d_{to\_lower\_compartment\_edge})^2}
\f]

Adding the wall thickness results in the fuselage diameter in negative z-direction:
\f[
    d_{fuselage\_z\_neg} = d_{inner\_fuselage\_z\_neg} + t_{wall}
\f]

#### Fuselage diameter in positive z-direction
The fuselage diameter in positive z-direction \f$d_{fuselage\_z\_pos}\f$ is determined by the passenger accommodation. It can be calculated in the following way.
Firstly, the inner fuselage height (equals outer cabin height) can be determined:
\f[
    d_{inner\_fuselage\_z\_pos} = h_{aisle\_standing} - o_{cabin\_floor} + h_{system\_bay}
\f]

In which
- \f$h_{aisle\_standing}\f$ - passenger aisle standing height
- \f$o_{cabin\_floor}\f$ - cabin floor offset
- \f$h_{system\_bay}\f$ - system bay height above cabin

Adding the wall thickness leads to the fuselage diameter in positive z-direction.
\f[
    d_{fuselage\_z\_pos} = d_{inner\_fuselage\_z\_pos} + t_{wall}
\f]

### Fuselage height
The total height of the fuselage can be determined by summing up the fuselage diameters in positive and negative z-direction:
\f[
    h_{fuselage} = d_{fuselage\_z\_pos} + d_{fuselage\_z\_neg}
\f]

@note If the `force_circle_cross_section` mode is selected, fuselage height and width are set to the maximum of both.

## Mass estimation {#mass-estimation}
The following masses are estimated:
- Fuselage structure
- Operator items
- Furnishing

Please refer to _Synthesis of Subsonic Airplane Design_ by E. Torenbeek<sup>[3]</sup> and the Certification Specifications<sup>[4]</sup> for further information.

@note All masses are estimated in accordance with the CPACS standard.
<!-- ## Estimate positions and COG -->

## Generate fuselage shape {#generate-shape}
The fuselage shape is generated using the calculated data and the reference ellipses (see the [getting started](getting_started.md) page for more information). The final geometry is written to the `fuselage_design_ellipses.json` file.
The aircraft is divided into three sections: A cockpit section, followed by a constant section, and the tail section. 
The steps of the shape generation are basically the same for all aircraft sections:
1. Calculate the section length as a percentage of the fuselage length<sup>*</sup>.
2. Proportionally adjust the given reference geometry to match the actual geometry using scaling factors. Therefore, separate scaling factors are calculated for
    - the x-direction (lengthwise),
    - the y-direction (widthwise), and
    - the z-directions (upper and lower heights).
3. Calculate new coordinates as well as ellipses for visualization purposes.

<sup>*</sup> The length of the constant section is determined by subtracting the length of the cockpit and the tail section from the entire fuselage length.

___
<sup>[1]</sup> Prof. Dr.-Ing. Juergen Thorbeck TU Berlin (2006), Script "Flugzeugentwurf I und II" chapter A.<br>
<sup>[2]</sup> M.Sc. Andreas Gobbin (2015), Master Thesis "Numerische Modellierung des Auslegungsprozesses für Passagierkabinen von Verkehrsflugzeugen unter Berücksichtigung der wichtigsten Auslegungsforderungen und Implementierung in MatLab".<br>
<sup>[3]</sup> Egbert Torenbeek, Synthesis of Subsonic Airplane Design (1982), Delft University Press.<br>
<sup>[4]</sup> European Union Aviation Safety Agency (2024),  CS-25 Large Aeroplanes - Amendment 28.