# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2024 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

def payload_tube_wall_thickness_calculation(dict_ac_exchange, passenger_cabin_width, runtime_output):
    """ Calculates wall thickness from given cabin width.
        References and calculation method:
            [1] Prof. Dr.-Ing. Juergen Thorbeck TU-Berlin (2006), Script "Flugzeugentwurf I und II" page: XYZ
                wall_thickness = 0.02 * cabin_width + 2.5" [inch]

    :param dict dict_ac_exchange: Dict containing parameter and according values from aircraft exchange file
    :param dict passenger_cabin_width: Dict containing passenger cabin width for each class and each payload tube
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :return list payload_tube_wall_thickness: dict containing the payload tube wall thicknesses
    """
    ''' initialize local parameter '''
    payload_tube_wall_thickness = {}

    # Estimate payload tube wall thickness for each tube according to [1]
    for tube in range(0, dict_ac_exchange['number_of_payload_tubes']):
        max_cabin_width_per_tube = 0
        for key, value in passenger_cabin_width.items():
            max_cabin_width_per_tube = max(max_cabin_width_per_tube, value[tube])

        payload_tube_wall_thickness['payload_tube_' + str(tube)] = round(0.02 * max_cabin_width_per_tube + 2.5, 2)

    ''' debug print '''
    runtime_output.debug('Debug: The payload_tube_wall_thickness_calculation function was successfully executed!')

    return payload_tube_wall_thickness
