# Getting started {#getting-started}
This guide will show you the basic usage of **initial_sizing**. Following steps are necessary (if you are new to UNICADO check out the [settings and outputs](#settingsandoutputs) first!)

## Step-by-step

It is assumed that you have the `UNICADO Package` installed including the executables and the engine database. In case you are a developer, you need to build the tool first (see [build instructions on UNICADO website](https://unicado.pages.rwth-aachen.de/unicado.gitlab.io/developer/build/cpp/)).

1. Create a dummy `aircraft_exchange_file` (minimal required input see [here](#acXML))
2. Fill out the configuration file - change at least:
    - in `control_settings` 
        - `aircraft_exchange_file_name` and `aircraft_exchange_file_directory` to your respective settings
        - `console_output` at least to `mode_1`
        - `plot_output` to false (or define `inkscape_path` and `gnuplot_path`)
    - in `program_settings`
        - the initial assumptions of values for the stated parameters
3. Open terminal and run **initialSizing**

Following will happen:
- you see output in the console window
- a HTML report is created in the directory of `aircraft_exchange_file_directory` (no plots if they are turned off)
- results are saved in the _acXML_ file


## Settings and outputs {#settingsandoutputs}
Generally, we use 2 files to set our configuration in UNICADO:
- the aircraft exchange file (or _acXML_) includes
    - data related inputs (e.g. range, pax number, cargo)
    - data related outputs (e.g. MTOM, OME)
- the configuration file `initial_sizing_conf.xml` (or _configXML_) includes
    - control settings (e.g. enable/disable generating plots)
    - program settings (e.g. set parameters to consider for specific technologies or change of methods)

### Aircraft exchange file
@note _acXML_ is an exchange file - we agreed on that only data will be saved as output which is needed by another tool!

**Inputs**: 
The following is needed from the _acXML_:
1) the accomodation requirements (pax number, pax mass, luggage mass, cargo mass), 
2) the mission requirements (range, reserves, TOFL, cruise speed and altitude, approach speed),
3) the user settings of the energy carrier

Naturally, the initial_sizing needs an assumption for the initial MTOM to start the iteration of MTOM. This initial MTOM is calculated from the pax number requirement in the _acXML_ 

Additionally, the user settings need to be defined. In the node `/aircraft_exchange\_file/requirements_and_specifications/design_specification` (for more information on the variables, please read the description in the _acXML_).

**Outputs**: 

The following is written into the _acXML_:
1) the Maximum Takeoff Mass (MTOM), 
2) the Operating Mass Empty (OME),
3) the Design Sizing Point which consists of the wing loading and the Thrust to weight ratio needed to fulfil the TLARs 
