# Getting started
This section will guide you through the necessary steps to get the _landing\_gear\_design_ module up and running. It contains information on tool requirements and design parameters.

- [Design method selection](#design-method-selection) - How to set the design method?
- [Aircraft exchange file](#aircraft-exchange-file) - Get information on necessary parameters from the _acXML_.
- [Module configuration file](#module-configuration-file) - Dive into landing gear design specific parameters.
- [Additional requirements](#additional-requirements) - Is anything else necessary to get the module running?
- [Next steps](#next-steps) - How to proceed?

@note It is assumed that you have the `UNICADO package` installed including the executables and UNICADO libraries.

Generally, we use two files to set or configure modules in UNICADO:
- The aircraft exchange file (or _acXML_) includes
    - data related inputs (e.g., configuration type) and
    - data related outputs (e.g., component design data).
- The module configuration file `landing_gear_design_conf.xml` (also _configXML_) includes
    - control settings (e.g., enable/disable generating plots) and
    - program settings (e.g., information on limitations and clearances).

In the following sections you will find more information on how to configure these files to suit your needs.

## Design method selection {#design-method-selection}
The calculation method is automatically chosen based on the following data from the aircraft exchange and module configuration file:

Parameter                  | File          | Example <sup>*</sup>          |
:--------------------------|---------------|:------------------------------|
Undercarriage definition   | _acXML_       | wing_mounted                  |
Calculation fidelity       | _configXML_   | empirical                     |
Method name                | _configXML_   | landing_gear_design_tu_berlin |
Energy carrier type        | _acXML_       | kerosene                      |

<sup>*</sup> This example defines a generic short and medium range tube-and-wing aircraft.

Thus, it must be ensured that this data is available. More information on required data can be found in the following sections.

## Aircraft exchange file requirements {#aircraft-exchange-file}
_landing\_gear\_design_ can be single executed without the execution of any other module. The only prerequisite is a complete `requirements_and_specifications` block in the aircraft exchange file.

<!-- To single execute the _fuselage\_design_ module, we need an _acXML_ file that already contains the output data from the following tools:
- _module\_name_
- ... -->

The following data should be available in the _acXML_ (2. and 3. are optional):
1. Requirements and specifications
    - Design specification
        - Configuration information
            - Fuselage definition: Fuselage type
            - Undercarriage definition: Undercarriage definition, undercarriage retractability
            - Wing definition: Wing mounting
        - Energy carrier(s)
        - Propulsion: Positioning of propulsor element(s)
    - Requirements
        - Top level aircraft requirements
            - Flight envelope information: Maximum approach speed, maximum takeoff stall speed
            - Pavement classification number
2. Analysis
    - Mission: Taxi fuel takeoff for design mission
    - Masses, CG, inertia
        - Manufacturer mass empty
        - Maximum takeoff mass
        - Maximum landing mass
        - Most afterward mass: COG position
        - Most forward mass: COG position
        - Design mass: COG position
3. Component design: Geometrical data of
    - Fuselage
        - Position
        - Information on fuselage sections
            - Upper height
            - Lower height
            - Width
        - Information on payload tubes
            - Payload tube front reference points
            - Payload tube aft reference points
    - Wing
        - (Position)
        - Symmetry information
        - Information for wing sections
            - Chord origin
            - Chord length
    - Propulsion
        - Information on nacelle sections
            - Width
            - Height
        - Information on engine: Position
    - Landing gear<sup>*</sup>
        - Position
        - Tool level

<sup>*</sup> Available from the second iteration loop.

@note When the UNICADO workflow is executed the tool is run automatically. In this case, all the required data should be available anyway.

## Module configuration file {#module-configuration-file}
The _configXML_ is structured into two blocks: the control and program settings.

The control settings are standardized in UNICADO and will not be described in detail here. But to get started, you have to change at least
- the `aircraft_exchange_file_name` and `aircraft_exchange_file_directory` to your respective settings,
- the `console_output` at least to `mode_1`, and
- the `plot_output` to false (or define `inkscape_path` and `gnuplot_path`).

@note If the tool is executed via the workflow, those settings are set by the workflow settings.

The program settings are structured like this (descriptions can be found in the `landing_gear_design_conf.xml`):

```plaintext
Program Settings
|- Configuration (ID="wing_mounted")
|  |- Fidelity name
|  |- Method name
|  |- Fidelity (ID="empirical")
|  |  |- Landing gear design tu berlin
|  |  |  |- General
|  |  |  |  |- Sizing mode
|  |  |  |  |  |- Setting use existing landing gear
|  |  |  |  |  |  |- Name of existing geometry file
|  |  |  |  |  |  |- Use as starting point
|  |  |  |  |- Ground strike limitations
|  |  |  |  |  |- Tail strike limit
|  |  |  |  |  |- Turnover limit
|  |  |  |  |  |- Wing strike limit
|  |  |  |  |- Nacelle clearance
|  |  |  |  |- Strut suspension
|  |  |  |  |  |- Strut suspension travel
|  |  |  |  |- Landing gear bay keel beam width
|  |  |  |  |- Landing gear mass correction factor
|  |  |  |- Specific
|  |  |  |  |- ACN method
|  |  |  |  |  |- Use target PCN
|  |  |  |  |  |- Coverages
|  |  |  |  |  |- Use specific california bearing ratio for flexible pavement
|  |  |  |  |  |  |- Specific california bearing ratio for flexible pavement
|  |  |  |  |  |- Use specific alpha value
|  |  |  |  |  |  |- Specific alpha value
|  |  |  |  |  |- Select new alpha from curve
|  |  |  |  |  |  |- Use Boeing proposals
|  |  |  |  |- Nose gear parameter
|  |  |  |  |  |- Minimum number of nose gear tires per strut
|  |  |  |  |  |- Use specific number of nose gear struts
|  |  |  |  |  |  |- Specific number of nose gear struts
|  |  |  |  |  |- Use specific number of nose gear tires per strut
|  |  |  |  |  |  |- Specific number of nose gear tires per strut
|  |  |  |  |  |- Use specific nose gear starting x-position
|  |  |  |  |  |  |- Specific nose gear starting x-position
|  |  |  |  |- Main gear parameter
|  |  |  |  |  |- Minimum number of main gear tires per strut
|  |  |  |  |  |- Dynamic range of number of main gear struts
|  |  |  |  |  |  |- Maximum number of main gear struts
|  |  |  |  |  |- Use specific number of main gear struts
|  |  |  |  |  |  |- Specific number of main gear struts
|  |  |  |  |  |- Use specific number of main gear tires per strut
|  |  |  |  |  |  |- Specific number of main gear tires per strut
|  |  |  |  |  |- Dynamic change of number of main gear tires per strut
|  |  |  |  |  |  |- Maximum number of main gear tires per strut
|  |  |  |  |  |- Minimum required wheel track
|  |  |  |  |  |- Minimum required wheel  base
```

## Additional requirements {#additional-requirements}

### Landing gear library
The landing gear library contains files that are necessary to generate a valid landing gear design.

#### Tire list
The EASA ETSO (European Technical Standard Order) tire list (`EASA_ETSO_tire_list_2022.xml`) contains data on several nose and main landing gear tires. The following values are provided:
- Tire size
- Diameters
- Rated pressure, speed, load, and ply
- Tire weight

The data is used to find matching tires for the main and nose gear.

#### Bridgestone manuals
Valuable information on the tire selection can be found in the Bridgestone manuals. There you can find information on cut depths, lengths limits and useful terminology, as well as tire specifications.

## Next steps {#next-steps}
The next step is to [run the _landing\_gear\_design_ module](run_your_first_design.md).