/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 * 
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "operating_conditions.h"

#include "../mission_file_data_handler/mission_file_data_handler.h"

/* Initialization of attributes for the OperatingConditions object with the constructor */
OperatingConditions::OperatingConditions(std::vector<MissionFileDataHandler::MissionDataSet>* mission_data)
    :
    mission_step(0),
    rating(""),
    derate(1.),
    CI(0.),
    config(""),
    bleed_times(),
    bleed_values(),
    shaft_power_times(),
    shaft_power_values(),
    background_bleed(0.),
    background_shaft_power(0.),
    mission_data(mission_data) {
}

/* Destructor of the OperatingConditions object */
OperatingConditions::~OperatingConditions() {
}

void OperatingConditions::set_segment_operating_conditions(const uint16_t &i) {
    this->mission_step = i;
    this->config = (*mission_data).at(i).config;
    this->rating = (*mission_data).at(i).rating;
    this->derate = (*mission_data).at(i).derate;
    this->CI = 0.;
    if ((*mission_data).at(i).bleed_schedule.size()) {
        for (unsigned int j(0); j < (*mission_data).at(i).bleed_schedule.size(); j++) {
            this->bleed_times.push_back((*mission_data).at(i).bleed_schedule.at(j).time);
            this->bleed_values.push_back((*mission_data).at(i).bleed_schedule.at(j).value);
        }
    }
    if ((*mission_data).at(i).shaft_power_schedule.size()) {
        for (unsigned int j(0); j < (*mission_data).at(i).shaft_power_schedule.size(); j++) {
            this->shaft_power_times.push_back((*mission_data).at(i).shaft_power_schedule.at(j).time);
            this->shaft_power_values.push_back((*mission_data).at(i).shaft_power_schedule.at(j).value);
        }
    }
    this->background_bleed = (*mission_data).at(i).background_bleed;
    this->background_shaft_power = (*mission_data).at(i).background_shaft_power;
}

void OperatingConditions::delete_used_bleed_and_shaft_power_offtakes(const double& time_step) {
    if (!this->bleed_times.empty()) {
        double time_sum(0.);
        while (!this->bleed_times.empty() && time_sum < time_step) {
            if (this->bleed_times.front() > time_step) {
                this->bleed_times.front() -= time_step;
                break;
            } else {
                time_sum += this->bleed_times.front();
                this->bleed_times.erase(this->bleed_times.begin());
                this->bleed_values.erase(this->bleed_values.begin());
            }
        }
    }
    if (!this->shaft_power_times.empty()) {
        double time_sum(0.);
        while (!this->shaft_power_times.empty() && time_sum < time_step) {
            if (this->shaft_power_times.front() > time_step) {
                this->shaft_power_times.front() -= time_step;
                break;
            } else {
                time_sum += this->shaft_power_times.front();
                this->shaft_power_times.erase(this->shaft_power_times.begin());
                this->shaft_power_values.erase(this->shaft_power_values.begin());
            }
        }
    }
}
