/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 * 
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef MISSION_ANALYSIS_SRC_MISSION_ANALYSIS_H_
#define MISSION_ANALYSIS_SRC_MISSION_ANALYSIS_H_

#include <string>
#include <vector>
#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

/** \class MissionAnalysis
 *  \brief This class contains the whole tool and its methods
 */
class MissionAnalysis : public Module {
 public:
    MissionAnalysis(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion);
    ~MissionAnalysis() = default;

    void initialize() override { missionStrategy_.initializeStrategy(); };
    void run() override { missionStrategy_.runStrategy(); };
    void update() override { missionStrategy_.updateStrategy(); };
    void report() override { missionStrategy_.reportStrategy(); };
    void save() override {
        missionStrategy_.saveStrategy();
        rtIO_->saveAcXML();
    };

 private:
    StrategySelector missionStrategy_;
};

#endif // MISSION_ANALYSIS_SRC_MISSION_ANALYSIS_H_
