/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef performance_assessment_SRC_TAW_DEFAULTMETHODS_CEILINGPERFORMANCE_LOW_FIDELITY_CEILINGPERFORMANCE_H_
#define performance_assessment_SRC_TAW_DEFAULTMETHODS_CEILINGPERFORMANCE_LOW_FIDELITY_CEILINGPERFORMANCE_H_

#include <vector>
#include <memory>

#include "../abstractCeilingPerformance.h"

class node;
class aircraft;

using std::vector;

namespace low {

/**\class ceilingPerformance Global class that contains the ceiling performances
*
*/
class ceilingPerformance : public abstractCeilingPerformance{
 public:


    /** \brief Calculate the aircraft ceiling
    */
    void doCeilingCalculation() override;

    /** \brief Constructor ceiling performance
    */
    explicit ceilingPerformance(std::shared_ptr<aircraft> myAcftPt);

    /** \brief Destructor ceiling performance
    */
    virtual ~ceilingPerformance();

 private:
    /**\brief Function calculates the maximum altitude, at which the rate of climb (ROC) can be achieved
    *\param Mass Aircraft mass (kg)
    *\param ROC Aircraft rate of climb (ft/min)
    *\param Mach Aircraft Mach number (-)
    *\param startAlt Initial aircraft altitude (ft)
    *\param OEI Switch if one engine is inoperative (true/false)
    *\return Aircraft ceiling (ft)
    */
    double iterateForCeiling(double Mass, double ROC, double Mach, double startAlt, bool OEI);

    /**\brief Check whether service ceiling is sufficient
    *\return True or false
    */
    bool checkForInitialCruiseAlt();

    /**\brief Check whether the maximum flight altitude can be reached
    *\return True or false
    */
    bool checkForMaxAlt();

    /**\brief Check if the initial Cruise Mach number is sufficient
    *\return True or false
    */
    bool checkForInitialCruiseMach();

    /**\brief Check whether service ceiling with one engine inoperative can be reached
    *\return True or false
    */
    bool checkForOEICruiseAlt();

    std::shared_ptr<aircraft> theAcftPt;
};

}  // namespace low
#endif  // performance_assessment_SRC_TAW_DEFAULTMETHODS_CEILINGPERFORMANCE_LOW_FIDELITY_CEILINGPERFORMANCE_H_
