/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef performance_assessment_SRC_TAW_DEFAULTMETHODS_FLIGHTENVELOPES_LOW_FIDELITY_FLIGHTENVELOPES_H_
#define performance_assessment_SRC_TAW_DEFAULTMETHODS_FLIGHTENVELOPES_LOW_FIDELITY_FLIGHTENVELOPES_H_

#include <unitConversion/unitConversion.h>

#include <vector>
#include <memory>

#include "../abstractFlightEnvelopes.h"
#include "../../ceilingPerformance/abstractCeilingPerformance.h"
#include "../../aircraft.h"

//class aircraft;

using std::vector;

namespace low {

/**\class flightEnvelopes Global class that contains informations about the flight envelope
*
*/
class flightEnvelopes : public abstractFlightEnvelopes {
 public:
    flightEnvelopes(std::shared_ptr<aircraft> myAcft);

    /**\brief Function to compute the dive speed limits
    *
    */
    void doDiveSpeedLimits() override;

    /**\brief Function to compute speed and height data
    *\param ceilingPerf Performance of the aircraft for different gross masses at ceiling (-)
    */
    void doFlightEnvelope(std::shared_ptr<abstractCeilingPerformance> ceilingPerf) override;

    /**\brief constructor flightEnvelopes
    *\param myAircraft Address to the aircraft object
    */
    // explicit flightEnvelopes(std::shared_ptr<aircraft> myAcftPt);

    /**\brief Destructor flightEnvelopes
    *
    */
    virtual ~flightEnvelopes();

 private:
    // std::shared_ptr<aircraft> theAcftPt; /**< Pointer to the aircraft object */

    /**\brief Function calculates the stall speeds for different altitudes
    *
    */
    void getStallingLimit();

    /**\brief Function calculates the maximum operating speeds for different altitudes
    *\param theCrossOverAlt Aircraft crossover altitude (m)
    */
    void getMMOLimit(double theCrossOverAlt);

    /**\brief Function calculates the dive speeds for different altitudes
    *\param theCrossOverAlt Aircraft crossover altitude (m)
    */
    void getDiveLimit(double theCrossOverAlt);

    /**\brief Function returns the crossover altitude
    *\param theSpeed Aircraft speed (m/s)
    *\param theMach Mach number (-)
    *\return crossover altitude (m)
    */
    double getCrossOverAlt(double theSpeed, double theMach);
};
}  // namespace low
#endif  // performance_assessment_SRC_TAW_DEFAULTMETHODS_FLIGHTENVELOPES_LOW_FIDELITY_FLIGHTENVELOPES_H_
