/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_THETORQUELIMITERS_H_
#define SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_THETORQUELIMITERS_H_

#include <string>

/** \brief contains all properties of the torque limiters
 */
class theTorqueLimiters {
 public:
    double Mass;/**<[kg] mass of the torque limiter */
    double efficiencyFactor;/**<efficiency factor of the torque limiter */

    /** \brief calculates the torque limiter mass
     *
     * \param deviceType string
     * \param totalActuationMass double: [kg]
     * \return void
     *
     */
    void getMass(const std::string& deviceType, double totalActuationMass);

    explicit theTorqueLimiters(const std::string& Type);
    virtual ~theTorqueLimiters();
};

#endif // SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_THETORQUELIMITERS_H_
