/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include <string>
#include <vector>
#include <memory>
#include <filesystem>
#include <map>


#include <moduleBasics/strategySelector.h>
#include "systemsDesign.h"
#include "standardSystemsDesign.h"

namespace fs = std::filesystem;

systemsDesign::systemsDesign(const int argc, char *argv[], const std::string& toolName, const std::string& toolVersion) : Module(argc, argv, toolName, toolVersion) {
    /* at the moment systemsDesign only offers the STANDARD route */
    rtIO_ = get_RuntimeIO();
    std::string method = rtIO_->moduleConfig.at("program_settings/modes/value");
    route_ = {method};
    strategy_.setStrategy(routing_(route_)(rtIO_));
}

strategyaccess systemsDesign::routing_(const std::vector<std::string>& route) {
    /* Routing table with only one case */
    std::map<std::string, strategyaccess> table = {
        {"STANDARD", [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<standardSystemsDesign>(arg);}},
    };
    return table[route.at(0)];
}
