/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef SYSTEMS_DESIGN_SRC_WEIGHTSANDCGS_H_
#define SYSTEMS_DESIGN_SRC_WEIGHTSANDCGS_H_

#include <string>
#include <vector>
#include <memory>
#include "systemsIOData.h"
#include "standardData.h"

class weightsAndCGs {
 private:
    std::shared_ptr<systemsIOData> data_; /*<-- IOData object*/

 public:
    std::vector<aircraftSystem*> System;/**vector containing all systems*/

    /** \brief Calls all functions for mass and center of gravity calculations
     * \return void
    */
    void getWeights();

    explicit weightsAndCGs(std::shared_ptr<systemsIOData> data);
    virtual ~weightsAndCGs();

 private:
    /** \brief calculates mass and cg of the propulsion group
     *
     * \return void
     *
     */
    void getPropulsionGroup();
    /** \brief calculates mass and cg of the systems group
     *
     * \return void
     *
     */
    void getSystemsGroup();
    /** \brief calculates mass and cg of the furnishings group
     *
     * \return void
     *
     */
    void getFurnishingsGroup();
    /** \brief calculates mass and cg of the operator items group
     *
     * \return void
     *
     */
    void getOperatorItems();
    /** \brief calculates mass and cg of the "not allocated" group
     *
     * \return void
     *
     */
    void getNotAllocatedSystems();

    /** \brief getter function for systems from systemArhcitecture
     *
     * \return void
     *
     */
    void getAllSystems();

    /** \brief sums up the masses of all systems excluding masses of accommodation and operator items calculated in fuselageDesing 
     * \return void
    */
    void getTotalMass();
};

#endif // SYSTEMS_DESIGN_SRC_WEIGHTSANDCGS_H_
