# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2024 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

"""Module providing plotting functionalities for current calculation method."""
# Import standard libraries.
import os
from matplotlib import pyplot as plt
import numpy as np


def method_plot(paths_and_names, routing_dict, data_dict, method_specific_output_dict, runtime_output):
    """Plot function.

    This function is responsible for creating plots.
    [Add further information here...]

    :param dict paths_and_names: Dictionary containing system paths and ElementTrees
    :param dict routing_dict: Dictionary containing routing parameters
    :param dict data_dict: Dictionary containing results of module execution
    :param dict method_specific_output_dict: Dictionary containing method specific output data
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :return: None
    """

    # wing_section_dict = data_dict['geometry']['wing']['sections']

    # Plot for kerosene tanks.
    # match routing_dict['user_layer']:
    #     case 'kerosene':
    #         # Plot wing contour.
    #         section_list = data_dict['geometry']['wing']['information']['wing_section_list']
    #         x_wing_contour_leading_edge = [wing_section_dict[section]['position']['x']
    #                                        for section in section_list]
    #         x_wing_contour_trailing_edge = [wing_section_dict[section]['position']['x']
    #                                         + wing_section_dict[section]['chord_length']
    #                                         for section in reversed(section_list)]
    #         x_wing_contour = x_wing_contour_leading_edge + x_wing_contour_trailing_edge
    #         y_wing_contour_leading_edge = [wing_section_dict[section]['position']['y']
    #                                         for section in section_list]
    #         y_wing_contour_trailing_edge = [wing_section_dict[section]['position']['y']
    #                                         for section in reversed(section_list)]
    #         y_wing_contour = y_wing_contour_leading_edge + y_wing_contour_trailing_edge
    #         # Plot tank contour.
    #         tank_list = ['tank_4', 'tank_0', 'tank_1', 'vent_tank']
    #         x_tank_contour_leading_edge= [data_dict[tank]['geometry']['total']['position']['x']
    #                                       for tank in tank_list]
    #         x_tank_contour_trailing_edge= [data_dict[tank]['geometry']['total']['position']['x']
    #                                        + data_dict[tank]['geometry']['inner_surface']['width']
    #                                       for tank in reversed(tank_list)]
    #         x_tank_contour = x_tank_contour_leading_edge + x_tank_contour_trailing_edge
    #         y_tank_contour_leading_edge = [data_dict[tank]['geometry']['total']['position']['y']
    #                                         for tank in tank_list]
    #         y_tank_contour_trailing_edge = [data_dict[tank]['geometry']['total']['position']['y']
    #                                        for tank in reversed(tank_list)]
    #         y_tank_contour = y_tank_contour_leading_edge + y_tank_contour_trailing_edge
    #         # Center tank.
    #         x_center_tank = [
    #             data_dict['tank_4']['geometry']['total']['position']['x'],
    #             data_dict['tank_4']['geometry']['total']['position']['x'],
    #             (data_dict['tank_4']['geometry']['total']['position']['x']
    #              + data_dict['tank_4']['geometry']['outer_surface']['width']),
    #             (data_dict['tank_4']['geometry']['total']['position']['x']
    #              + data_dict['tank_4']['geometry']['outer_surface']['width'])
    #         ]
    #         y_center_tank = [
    #             data_dict['tank_4']['geometry']['inner_surface']['position']['y'],
    #             data_dict['tank_4']['geometry']['outer_surface']['position']['y'],
    #             data_dict['tank_4']['geometry']['outer_surface']['position']['y'],
    #             data_dict['tank_4']['geometry']['inner_surface']['position']['y']
    #         ]
    #         # Inner wing tank.
    #         x_inner_wing_tank = [
    #             data_dict['tank_0']['geometry']['total']['position']['x'],
    #             data_dict['tank_1']['geometry']['total']['position']['x'],
    #             (data_dict['tank_1']['geometry']['total']['position']['x']
    #              + data_dict['tank_1']['geometry']['inner_surface']['width']),
    #             (data_dict['tank_0']['geometry']['total']['position']['x']
    #              + data_dict['tank_0']['geometry']['inner_surface']['width'])
    #         ]
    #         y_inner_wing_tank = [
    #             data_dict['tank_0']['geometry']['inner_surface']['position']['y'],
    #             data_dict['tank_0']['geometry']['outer_surface']['position']['y'],
    #             data_dict['tank_0']['geometry']['outer_surface']['position']['y'],
    #             data_dict['tank_0']['geometry']['inner_surface']['position']['y']
    #         ]
    #         # Outer wing tank.
    #         x_outer_wing_tank = [
    #             data_dict['tank_1']['geometry']['total']['position']['x'],
    #             data_dict['vent_tank']['geometry']['total']['position']['x'],
    #             (data_dict['vent_tank']['geometry']['total']['position']['x']
    #              + data_dict['vent_tank']['geometry']['inner_surface']['width']),
    #             (data_dict['tank_1']['geometry']['total']['position']['x']
    #              + data_dict['tank_1']['geometry']['inner_surface']['width'])
    #         ]
    #         y_outer_wing_tank = [
    #             data_dict['tank_1']['geometry']['inner_surface']['position']['y'],
    #             data_dict['tank_1']['geometry']['outer_surface']['position']['y'],
    #             data_dict['tank_1']['geometry']['outer_surface']['position']['y'],
    #             data_dict['tank_1']['geometry']['inner_surface']['position']['y']
    #         ]
    #         # Plot.
    #         plt.plot(x_wing_contour, y_wing_contour, color='black')
    #         num = int(round(wing_section_dict['wing_tip']['position']['y']*100, 0))
    #         y_tmp = np.linspace(0.0, wing_section_dict['wing_tip']['position']['y'], num+1)
    #         plt.plot(data_dict['geometry']['wing']['interpolated_values']['x_coordinate_front_spar'], y_tmp,
    #                  color='grey')
    #         plt.plot(data_dict['geometry']['wing']['interpolated_values']['x_coordinate_rear_spar'], y_tmp,
    #                  color='grey')
    #         # plt.plot(x_tank_contour, y_tank_contour)
    #         plt.plot(x_center_tank, y_center_tank, color="red")
    #         plt.plot(x_inner_wing_tank, y_inner_wing_tank, color="green")
    #         plt.plot(x_outer_wing_tank, y_outer_wing_tank, color="blue")
    #         plt.axis('equal')
    #         plt.show()

    #         print()
    #     case 'liquid_hydrogen':
    #         print()
    # This is just a dummy code snippet. Insert your code here.
    runtime_output.warning('Warning: No "method_plot" function in "methodplot.py" file implemented yet.')
