# Introduction {#mainpage}
The aircraft’s mass plays a crucial role in determining flight performance and evaluating the design, with the ultimate goal being to minimize the operating empty mass. 🏋️‍♀️ Knowing individual masses is essential for calculating the center of gravity (CG) and determining the placement of critical components like the landing gear and wings. ✈️  The CG significantly affects the aircraft's stability and controllability. An improperly located CG can compromise flight safety, requiring careful planning to ensure it remains within allowable limits throughout the flight, including during fuel consumption and payload variations. This analysis is typically conducted through a weight and balance evaluation using a loading diagram :chart_with_upwards_trend:, which defines the permissible range for combinations of aircraft mass and CG positions. Mass considerations are also fundamental to cost estimation. As an aircraft’s mass increases, it requires more lift, which leads to higher drag, increased thrust demands, elevated fuel consumption, and ultimately greater fuel and operating costs. 💸

In UNICADO, the _weight\_and\_balance_analysis_ tool is used to compute the aircraft's masses, determine the CG positions, calculate mass moments of inertia, and generate the loading diagram. The terms "mass" and "weight" are often used interchangeably in aircraft design, though they are scientifically distinct. In this context, both terms are used to refer to the aircraft's mass.

## A User's Guide to Weight & Balance Analysis
This user documentation will guide you through all necessary steps to understand the tool as well as the necessary inputs and configurations to calculate the aircraft masses, CG positions, aircraft's moments of inertia and determine the loading diagramm with the most forward and most aft CG positions. 

The following pages will guide you through the theory behind and the process of computing and analysing the weight and balance within UNICADO:

- [Basic Concepts](basic-concepts.md)
- [Usage of the Weight & Balance Analysis Tool](usage.md)

So let's get started! 💪


## You are a Developer?

If you are familiar with these concepts and want to contribute - head over to the developers guide to get your own method running in UNICADO!

The following pages will help you understand the code structure:

- [Developer Guide](https://unicado.pages.rwth-aachen.de/unicado.gitlab.io/developer/developer-installation/)
- [Build Instructions](https://unicado.pages.rwth-aachen.de/unicado.gitlab.io/developer/build/general/)
- [How to Python in UNICADO](https://unicado.pages.rwth-aachen.de/unicado.gitlab.io/developer/style/python-modularization/)
- [Weight & Balance Analysis Tool Structure](usage.md)

We appreciate it!

