# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2024 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

"""Acommodation IO"""

import pandas as pd


class AcommodationIO:
    def __init__(self) -> None:
        self.number_of_passengers_per_row = None
        self.mass_per_passenger = None
        self.rows = None
        self.seating_spacing_x_coordinate = None
        self.fuselage_type = None

    def read(self, xml_node, excel_file):

        base_path = "./requirements_and_specifications/design_specification/transport_task/"

        self.rows = int(xml_node.find(
            base_path + "passenger_definition/total_number_passengers/value").text) / 6
        # fixed nr of seats = 6 per row

        self.mass_per_passenger = float(xml_node.find(
            base_path + "passenger_definition/mass_per_passenger/value").text)

        seats_x_coordinate = [6.2232, 6.9598, 7.6964, 8.433, 9.1696, 9.9062, 10.6428, 11.3794, 12.116,
                              12.8526, 13.5892, 14.3258, 15.3302, 16.3302, 17.0414, 17.7526, 18.4638,
                              19.175, 19.8862, 20.5974, 21.3086, 22.0198, 22.731, 23.4422, 24.128, 24.8138,
                              25.4996, 26.1854, 26.8712, 27.557]
        max_number_of_passengers_per_row = [6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
                                            6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
                                            6, 6, 6, 6, 6, 6, 6, 6, 6, 6]  # max 180 PAX for 30 rows

        self.seating_spacing_x_coordinate = seats_x_coordinate[:int(self.rows)]
        self.number_of_passengers_per_row = max_number_of_passengers_per_row[:int(
            self.rows)]

        self.cargo_spacing_x_coordinate = range(5, 30)

        # self.fuselage_type = {
        #     "size": 'single_aisle',
        #     "number": 1,
        #     "decks": 1
        # }

        return self
