# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2024 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

import pytest

import xml.etree.ElementTree as ET
from basic.massPropertiesIO import MassPropertiesIO


@pytest.fixture
def empty_mass_properties():

    yield MassPropertiesIO()


class TestMassPropertiesIO:

    def test_initialize_zero_mass(self, empty_mass_properties):
        # Setup test
        empty_mass_properties.initialize_zero_mass()

        # Assert
        assert empty_mass_properties.mass == 0.0

    def test_initialize_zero_center_of_gravity(self, empty_mass_properties):
        empty_mass_properties.initialize_zero_center_of_gravity()

        for _, value in empty_mass_properties.center_of_gravity.items():
            assert value == 0.0

    def test_initialize_zero_inertia(self, empty_mass_properties):
        empty_mass_properties.initialize_zero_inertia()

        for _, value in empty_mass_properties.inertia.items():
            assert value == 0.0

    def test_initialize_zero(self, empty_mass_properties):
        empty_mass_properties.initialize_zero()

        assert empty_mass_properties.mass == 0.0

        for _, value in empty_mass_properties.center_of_gravity.items():
            assert value == 0.0

        for _, value in empty_mass_properties.inertia.items():
            assert value == 0.0
