# Basic Concepts {#BasicConcepts}

Designing a wing for an aircraft is by far one of the most challenging tasks. This topic provides basic information for wings.

If you are already familiar with the basic concepts, you can move on to the [Getting Started](getting-started.md).


### Available configurations
Here you can find available wing build methods from the _wing\_design_ tool inside UNICADO.
- _UNICADO is shipped natively with the cantilever wing method for a tube and wing configuration._
- _A basic Blended Wing body method is planned!_

<pre class='mermaid'>
  graph LR;
    A[Wing Design]-->B[Tube and Wing];
    B-->C[Cantilever];
    A-->D[Blended Wing body]
</pre>

<dl class="section bug">
  <dt>Important</dt>
  <dd>Since the documentation might be delayed to the development progress - this graph might not have all information yet</dd>
</dl>
___

### Wing Loading
Wing loading is the mass / weight of the aircraft distributed over its reference wing area.
- _Initial parameter to start design_
- _Wing Loading = M / S_ in (kg/m^2)
- _Wing Loading = M &times; g / S_ in (N/m^2)
- _M : Aircraft mass_
- _g : Gravitational acceleration_
- _Wing Loading &uarr; Higher speeds at takeoff necessary_
- _Wing Loading &darr; Lower speeds at takeoff_

### Wing Geometry
Understanding the wing geometry is crucial for designing an efficient wing. Below are key terms and their meanings:
- Aspect Ratio (_AR_): The ratio of the wingspan to the average chord length
  - _AR= b&sup2; / S_
  - _b : Wingspan_
  - _S : Wing reference area (projected area on ground from top view)_
  - _High AR (e.g. gliders) &rarr; increased aerodynamic efficiency (higher drag) but slender and more flexible wing._
  - _Low AR (e.g., fighter jets) &rarr; decreased aerodynmic efficiency and stiffer._

- Taper Ratio (&lambda;): The ratio of the tip chord to the root chord.
  - _&lambda;_ = _c_<sub>_tip_</sub> / _c_<sub>_root_</sub>
  - _A taper ratio of one indicates a rectangular wing._
  - _Reduced taper ratio can improve aerodynamic efficiency and reduce structural weight._

- Sweep Angle (&Phi;): The angle between the chord at a given position and a line perpendicular to the chord
  - _Increased sweep leads to higher overall speeds due to reduction of the mach number normal to the leading edge_
    - _backward sweep: increased aerodynamic load at the outer wing part &rarr; bad behaviour at high angle of attack (AoA)_
    - _forward sweep: decreased aerodynamic load at the outer wing part but increased structural load due to wing torsion effects_

- Dihedral / Anhedral Angle (&nu;): Effects wing clearance and roll stability due to sideslip
  - Common dihedral angle (positive) for low wing configuration
  - Common anhedral angle (negative) for shoulder or high wing configurations

- Kink: Discontinuity in the wing trailing edge due to change in trailing edge sweep
  - mostly occurs on aircraft from inner to outer wing (low configuration) which is affected by the engine and landing gear vice versa

### Airfoil selection
An airfoil defines the cross-sectional shape of a wing. The key characteristics include:
- Camber: Airfoil curvature
  - _High camber  - generates more lift but comes with increased drag_
  - _No camber (symmetrical) often used for aerobatic A/C_
  - _Chord: Defines the length of the line from leading to trailing edge_
  - _Thickness to Chord Ratio (t/c): maximum airfoil thickness in relation to its chord length_
  - _affects lift, drag and wing cross section_


### Spar Placements
Spars are the one of the main structural elements inside the wing to provide strength and rigidity
  - _Has effects size of slats, flaps and integral tank size_


### Winglet / Raked wingtip / Rakelet (not available yet):
Additional aerodynamic component at the tip of the main wing section
- _Used for induced drag reduction_
