/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef CONTROL_DEVICE_IO_H_
#define CONTROL_DEVICE_IO_H_

#include "relativePositionIO.h"

class ControlDevice {
 public:
  ControlDevice() = default;
  ControlDevice(const std::string& origin)
      : type(EndnodeReadOnly<std::string>(origin + "type")),
        deflection_full_negative(EndnodeReadOnly<double>(origin + "deflection/full_negative_deflection")),
        deflection_full_positive(EndnodeReadOnly<double>(origin + "deflection/full_positive_deflection")),
        position(RelativePosition(origin)) {}
  EndnodeReadOnly<std::string> type;
  EndnodeReadOnly<double> deflection_full_negative;
  EndnodeReadOnly<double> deflection_full_positive;
  RelativePosition position;

  void read(const node& xml) {
    type.read(xml);
    deflection_full_negative.read(xml);
    deflection_full_positive.read(xml);
    position.read(xml);
  }
};

#endif  // CONTROL_DEVICE_IO_H_