/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef POSITION_IO_H_
#define POSITION_IO_H_

#include <aircraftGeometry2/geometry/entity3d.h>
#include <aixml/endnode.h>

class PositionIO {
 public:
  PositionIO() = default;
  PositionIO(const std::string& origin, const std::string& component)
      : origin_(origin),
        component_(component),
        x(Endnode<double>(origin + "/x", "x position")),
        y(Endnode<double>(origin + "/y", "y position")),
        z(Endnode<double>(origin + "/z", "z position")) {}
  Endnode<double> x;
  Endnode<double> y;
  Endnode<double> z;

  geom2::Point_3 xyz() { return geom2::Point_3(x.value(), y.value(), z.value()); }

  void set_xyz(const geom2::Point_3& xyz) {
    x.set_value(xyz.x());
    y.set_value(xyz.y());
    z.set_value(xyz.z());
  }
  void set_xyz(const double x_value, const double y_value, const double z_value) {
    x.set_value(x_value);
    y.set_value(y_value);
    z.set_value(z_value);
  }

  void read(const node& xml) {
    x.read(xml);
    y.read(xml);
    z.read(xml);
  }

  void update(node& xml) {
    xml[origin_].setAttrib<std::string>("description", "position of " + component_);
    x.update(xml);
    y.update(xml);
    z.update(xml);
  }

 private:
  std::string component_{""};
  std::string origin_{""};
};

#endif  // POSITION_IO_H_