/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "wingDesign.h"

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

#include <iostream>
#include <vector>

#include "cantileverWingDesignTaw.h"
#include "lowWingDesignBwb.h"

WingDesign::WingDesign(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion)
    : Module(argc, argv, toolName, toolVersion) {
  std::string configuration = rtIO_->aircraft_configuration_type();
  std::string wing_type = "cantilever";
  
  /* Register existing strategies */
  /* tube and wing strategies */
  strategy.registerStrategy<taw::cantilever::Wing>({"tube_and_wing", "cantilever"});

  /* blended wing body strategies */
  strategy.registerStrategy<bwb::low::Wing>({"blended_wing_body", "cantilever"});
  
  /* Set desired strategy */
  strategy.setStrategy({configuration, wing_type}, rtIO_);
}
